SymbolMapEntry

Trait SymbolMapEntry 

pub trait SymbolMapEntry {
    // Required method
    fn address(&self) -> u64;

    // Provided method
    fn size(&self) -> u64 { ... }
}
An entry in a SymbolMap.

Required Methods

fn address(&self) -> u64

The symbol address.

Provided Methods

fn size(&self) -> u64

The symbol size.

0 means the symbol continues to the next entry in the symbol map, or to the end of the address space if it is the last entry.

Implementors

Source

impl<'data> SymbolMapEntry for ObjectMapEntry<'data>

Source

impl<'data> SymbolMapEntry for SymbolMapName<'data>