pub struct SymbolMapBuilder(/* private fields */);Expand description
A builder for a SymbolMap.
Implementations
Sourceimpl SymbolMapBuilder
impl SymbolMapBuilder
Sourcepub fn build<'data, O>(self, object: &O) -> SymbolMap<SymbolMapName<'data>>
pub fn build<'data, O>(self, object: &O) -> SymbolMap<SymbolMapName<'data>>
Read the symbols from an object file to create a symbol map.
The map will only contain defined text and data symbols. The dynamic symbol table will only be used if there are no debugging symbols.
If symbol sizes are unknown then we guess the size based on the next symbol or end of section.
This does not work well if multiple sections use the same base address, which is common for relocatable object files. The symbols will be overlapping, and the symbol returned by lookups may be indeterministic. Additionally, if the symbol size is unknown then we may use a symbol or section end address from a different section to guess its size.